import requests
import json

API_BASE_URL = "https://fantasy.premierleague.com/drf/"

class FPL():
    def user(self, user_id):
        """
        Returns a dictionary containing information about the user with the 
        given `user_id`.

        :param string user_id: A user's id

        Example output:

        .. code-block:: json

            {
              "entry": {
                "id": 3523615,
                "player_first_name": "Amos",
                "player_last_name": "Bastian",
                "player_region_id": 152,
                "player_region_name": "Netherlands",
                "player_region_short_iso": "NL",
                "summary_overall_points": 1310,
                "summary_overall_rank": 85421,
                "summary_event_points": 59,
                "summary_event_rank": 244725,
                "joined_seconds": 47803,
                "current_event": 23,
                "total_transfers": 25,
                "total_loans": 0,
                "total_loans_active": 0,
                "transfers_or_loans": "transfers",
                "deleted": false,
                "email": false,
                "joined_time": "2017-08-11T11:42:48Z",
                "name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                "bank": 1,
                "value": 1050,
                "kit": null,
                "event_transfers": 0,
                "event_transfers_cost": 0,
                "extra_free_transfers": 1,
                "strategy": null,
                "favourite_team": 12,
                "started_event": 1,
                "player": 7425806
              },
              "leagues": {
                "cup": [
                  {
                    "id": 49432119,
                    "entry_1_entry": 3523615,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_player_name": "Amos Bastian",
                    "entry_2_entry": 3577330,
                    "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f",
                    "entry_2_player_name": "craig johnston",
                    "is_knockout": true,
                    "winner": 3577330,
                    "tiebreak": null,
                    "own_entry": false,
                    "entry_1_points": 75,
                    "entry_1_win": 0,
                    "entry_1_draw": 0,
                    "entry_1_loss": 0,
                    "entry_2_points": 81,
                    "entry_2_win": 0,
                    "entry_2_draw": 0,
                    "entry_2_loss": 0,
                    "entry_1_total": 0,
                    "entry_2_total": 0,
                    "seed_value": null,
                    "event": 20
                  },
                  {
                    "id": 48936155,
                    "entry_1_entry": 3523615,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_player_name": "Amos Bastian",
                    "entry_2_entry": 1010689,
                    "entry_2_name": "Pilot Light 2017",
                    "entry_2_player_name": "stephen crozier",
                    "is_knockout": true,
                    "winner": 3523615,
                    "tiebreak": null,
                    "own_entry": false,
                    "entry_1_points": 91,
                    "entry_1_win": 0,
                    "entry_1_draw": 0,
                    "entry_1_loss": 0,
                    "entry_2_points": 54,
                    "entry_2_win": 0,
                    "entry_2_draw": 0,
                    "entry_2_loss": 0,
                    "entry_1_total": 0,
                    "entry_2_total": 0,
                    "seed_value": null,
                    "event": 19
                  }
                ],
                "h2h": [
                  {
                    "id": 314,
                    "entry_rank": null,
                    "entry_last_rank": null,
                    "entry_movement": null,
                    "entry_change": null,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Cup",
                    "is_cup": true,
                    "short_name": "cup",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "h",
                    "ko_rounds": 22,
                    "admin_entry": null,
                    "start_event": 17
                  }
                ],
                "classic": [
                  {
                    "id": 12,
                    "entry_rank": 15699,
                    "entry_last_rank": 24703,
                    "entry_movement": "up",
                    "entry_change": 9004,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Man Utd",
                    "short_name": "team-12",
                    "created": "2017-07-12T09:49:04Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 172,
                    "entry_rank": 261,
                    "entry_last_rank": 366,
                    "entry_movement": "up",
                    "entry_change": 105,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Netherlands",
                    "short_name": "region-152",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 275,
                    "entry_rank": 85073,
                    "entry_last_rank": 135095,
                    "entry_movement": "up",
                    "entry_change": 50022,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Gameweek 1",
                    "short_name": "event-1",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 313,
                    "entry_rank": 85421,
                    "entry_last_rank": 136017,
                    "entry_movement": "up",
                    "entry_change": 50596,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Overall",
                    "short_name": "overall",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 583,
                    "entry_rank": 2874,
                    "entry_last_rank": 3787,
                    "entry_movement": "up",
                    "entry_change": 913,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@FPL_Updates - \u00a3500 Prize",
                    "short_name": null,
                    "created": "2017-07-12T10:19:02Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1655,
                    "start_event": 1
                  },
                  {
                    "id": 1849,
                    "entry_rank": 420,
                    "entry_last_rank": 514,
                    "entry_movement": "up",
                    "entry_change": 94,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@FPLSecrets \u00a310 monthly prize",
                    "short_name": null,
                    "created": "2017-07-12T10:36:28Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 5216,
                    "start_event": 1
                  },
                  {
                    "id": 1867,
                    "entry_rank": 152,
                    "entry_last_rank": 199,
                    "entry_movement": "up",
                    "entry_change": 47,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "\/r\/soccer",
                    "short_name": null,
                    "created": "2017-07-12T10:36:47Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 5324,
                    "start_event": 1
                  },
                  {
                    "id": 4204,
                    "entry_rank": 1940,
                    "entry_last_rank": 2607,
                    "entry_movement": "up",
                    "entry_change": 667,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Official \/r\/FantasyPL Classic League",
                    "short_name": null,
                    "created": "2017-07-12T11:02:54Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 2611,
                    "start_event": 1
                  },
                  {
                    "id": 12110,
                    "entry_rank": 32,
                    "entry_last_rank": 39,
                    "entry_movement": "up",
                    "entry_change": 7,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "The Gift Experience - Win \u00a3100",
                    "short_name": null,
                    "created": "2017-07-12T12:30:24Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 40645,
                    "start_event": 1
                  },
                  {
                    "id": 45711,
                    "entry_rank": 165,
                    "entry_last_rank": 224,
                    "entry_movement": "up",
                    "entry_change": 59,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "WIN $3,000 of Dollarsandart",
                    "short_name": null,
                    "created": "2017-07-12T22:05:43Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 178060,
                    "start_event": 1
                  },
                  {
                    "id": 54728,
                    "entry_rank": 75,
                    "entry_last_rank": 111,
                    "entry_movement": "up",
                    "entry_change": 36,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "\/r\/reddevils",
                    "short_name": null,
                    "created": "2017-07-13T07:26:22Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 221213,
                    "start_event": 1
                  },
                  {
                    "id": 153984,
                    "entry_rank": 64,
                    "entry_last_rank": 84,
                    "entry_movement": "up",
                    "entry_change": 20,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Sean Graham Customer League ",
                    "short_name": null,
                    "created": "2017-07-18T09:04:08Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 647805,
                    "start_event": 1
                  },
                  {
                    "id": 159755,
                    "entry_rank": 48,
                    "entry_last_rank": 67,
                    "entry_movement": "up",
                    "entry_change": 19,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@bettingslip \u00a3100 league",
                    "short_name": null,
                    "created": "2017-07-18T14:28:55Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 116530,
                    "start_event": 1
                  },
                  {
                    "id": 230905,
                    "entry_rank": 158,
                    "entry_last_rank": 199,
                    "entry_movement": "up",
                    "entry_change": 41,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Opi's league - \u00a3150 prize pool",
                    "short_name": null,
                    "created": "2017-07-23T13:09:13Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 9881,
                    "start_event": 1
                  },
                  {
                    "id": 291211,
                    "entry_rank": 21,
                    "entry_last_rank": 25,
                    "entry_movement": "up",
                    "entry_change": 4,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Ime Property Ltd league",
                    "short_name": null,
                    "created": "2017-07-26T23:23:24Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1214941,
                    "start_event": 1
                  },
                  {
                    "id": 366152,
                    "entry_rank": 1,
                    "entry_last_rank": 1,
                    "entry_movement": "same",
                    "entry_change": null,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "'WolfPack'",
                    "short_name": null,
                    "created": "2017-07-31T17:40:53Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1529029,
                    "start_event": 1
                  },
                  {
                    "id": 490770,
                    "entry_rank": 4,
                    "entry_last_rank": 5,
                    "entry_movement": "up",
                    "entry_change": 1,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Serie A Now ",
                    "short_name": null,
                    "created": "2017-08-05T18:12:51Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 3700829,
                    "start_event": 1
                  },
                  {
                    "id": 743038,
                    "entry_rank": 1,
                    "entry_last_rank": 1,
                    "entry_movement": "same",
                    "entry_change": null,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "AJ's Angels",
                    "short_name": null,
                    "created": "2017-08-10T21:43:35Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1944860,
                    "start_event": 1
                  }
                ]
              }
            }
        """
        return requests.get("{}entry/{}".format(API_BASE_URL, user_id)).json()

    def user_history(self, user_id):
        """
        Returns a dictionary with the history of the user with the given
        `user_id`.

        :param string user_id: A user's id

        Example output:

        .. code-block:: json

            {
              "chips": [
                {
                  "played_time_formatted": "28 Aug 01:07",
                  "status": "played",
                  "name": "wildcard",
                  "time": "2017-08-28T00:07:04Z",
                  "chip": 1,
                  "entry": 3523615,
                  "event": 4
                }
              ],
              "entry": {
                "id": 3523615,
                "player_first_name": "Amos",
                "player_last_name": "Bastian",
                "player_region_id": 152,
                "player_region_name": "Netherlands",
                "player_region_short_iso": "NL",
                "summary_overall_points": 1310,
                "summary_overall_rank": 85421,
                "summary_event_points": 71,
                "summary_event_rank": 244725,
                "joined_seconds": 28357,
                "current_event": 23,
                "total_transfers": 25,
                "total_loans": 0,
                "total_loans_active": 0,
                "transfers_or_loans": "transfers",
                "deleted": false,
                "email": false,
                "joined_time": "2017-08-11T11:42:48Z",
                "name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                "bank": 1,
                "value": 1051,
                "kit": null,
                "event_transfers": 0,
                "event_transfers_cost": 0,
                "extra_free_transfers": 1,
                "strategy": null,
                "favourite_team": 12,
                "started_event": 1,
                "player": 7425806
              },
              "leagues": {
                "cup": [
                  {
                    "id": 49432119,
                    "entry_1_entry": 3523615,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_player_name": "Amos Bastian",
                    "entry_2_entry": 3577330,
                    "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f",
                    "entry_2_player_name": "craig johnston",
                    "is_knockout": true,
                    "winner": 3577330,
                    "tiebreak": null,
                    "own_entry": false,
                    "entry_1_points": 75,
                    "entry_1_win": 0,
                    "entry_1_draw": 0,
                    "entry_1_loss": 0,
                    "entry_2_points": 81,
                    "entry_2_win": 0,
                    "entry_2_draw": 0,
                    "entry_2_loss": 0,
                    "entry_1_total": 0,
                    "entry_2_total": 0,
                    "seed_value": null,
                    "event": 20
                  },
                  {
                    "id": 48936155,
                    "entry_1_entry": 3523615,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_player_name": "Amos Bastian",
                    "entry_2_entry": 1010689,
                    "entry_2_name": "Pilot Light 2017",
                    "entry_2_player_name": "stephen crozier",
                    "is_knockout": true,
                    "winner": 3523615,
                    "tiebreak": null,
                    "own_entry": false,
                    "entry_1_points": 91,
                    "entry_1_win": 0,
                    "entry_1_draw": 0,
                    "entry_1_loss": 0,
                    "entry_2_points": 54,
                    "entry_2_win": 0,
                    "entry_2_draw": 0,
                    "entry_2_loss": 0,
                    "entry_1_total": 0,
                    "entry_2_total": 0,
                    "seed_value": null,
                    "event": 19
                  }
                ],
                "h2h": [
                  {
                    "id": 314,
                    "entry_rank": null,
                    "entry_last_rank": null,
                    "entry_movement": null,
                    "entry_change": null,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Cup",
                    "is_cup": true,
                    "short_name": "cup",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "h",
                    "ko_rounds": 22,
                    "admin_entry": null,
                    "start_event": 17
                  }
                ],
                "classic": [
                  {
                    "id": 12,
                    "entry_rank": 15699,
                    "entry_last_rank": 24703,
                    "entry_movement": "up",
                    "entry_change": 9004,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Man Utd",
                    "short_name": "team-12",
                    "created": "2017-07-12T09:49:04Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 172,
                    "entry_rank": 261,
                    "entry_last_rank": 366,
                    "entry_movement": "up",
                    "entry_change": 105,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Netherlands",
                    "short_name": "region-152",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 275,
                    "entry_rank": 85073,
                    "entry_last_rank": 135095,
                    "entry_movement": "up",
                    "entry_change": 50022,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Gameweek 1",
                    "short_name": "event-1",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 313,
                    "entry_rank": 85421,
                    "entry_last_rank": 136017,
                    "entry_movement": "up",
                    "entry_change": 50596,
                    "entry_can_leave": false,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": false,
                    "entry_code": null,
                    "name": "Overall",
                    "short_name": "overall",
                    "created": "2017-07-12T09:49:05Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "s",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": null,
                    "start_event": 1
                  },
                  {
                    "id": 583,
                    "entry_rank": 2874,
                    "entry_last_rank": 3787,
                    "entry_movement": "up",
                    "entry_change": 913,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@FPL_Updates - \u00a3500 Prize",
                    "short_name": null,
                    "created": "2017-07-12T10:19:02Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1655,
                    "start_event": 1
                  },
                  {
                    "id": 1849,
                    "entry_rank": 420,
                    "entry_last_rank": 514,
                    "entry_movement": "up",
                    "entry_change": 94,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@FPLSecrets \u00a310 monthly prize",
                    "short_name": null,
                    "created": "2017-07-12T10:36:28Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 5216,
                    "start_event": 1
                  },
                  {
                    "id": 1867,
                    "entry_rank": 152,
                    "entry_last_rank": 199,
                    "entry_movement": "up",
                    "entry_change": 47,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "\/r\/soccer",
                    "short_name": null,
                    "created": "2017-07-12T10:36:47Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 5324,
                    "start_event": 1
                  },
                  {
                    "id": 4204,
                    "entry_rank": 1940,
                    "entry_last_rank": 2607,
                    "entry_movement": "up",
                    "entry_change": 667,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Official \/r\/FantasyPL Classic League",
                    "short_name": null,
                    "created": "2017-07-12T11:02:54Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 2611,
                    "start_event": 1
                  },
                  {
                    "id": 12110,
                    "entry_rank": 32,
                    "entry_last_rank": 39,
                    "entry_movement": "up",
                    "entry_change": 7,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "The Gift Experience - Win \u00a3100",
                    "short_name": null,
                    "created": "2017-07-12T12:30:24Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 40645,
                    "start_event": 1
                  },
                  {
                    "id": 45711,
                    "entry_rank": 165,
                    "entry_last_rank": 224,
                    "entry_movement": "up",
                    "entry_change": 59,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "WIN $3,000 of Dollarsandart",
                    "short_name": null,
                    "created": "2017-07-12T22:05:43Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 178060,
                    "start_event": 1
                  },
                  {
                    "id": 54728,
                    "entry_rank": 75,
                    "entry_last_rank": 111,
                    "entry_movement": "up",
                    "entry_change": 36,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "\/r\/reddevils",
                    "short_name": null,
                    "created": "2017-07-13T07:26:22Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 221213,
                    "start_event": 1
                  },
                  {
                    "id": 153984,
                    "entry_rank": 64,
                    "entry_last_rank": 84,
                    "entry_movement": "up",
                    "entry_change": 20,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Sean Graham Customer League ",
                    "short_name": null,
                    "created": "2017-07-18T09:04:08Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 647805,
                    "start_event": 1
                  },
                  {
                    "id": 159755,
                    "entry_rank": 48,
                    "entry_last_rank": 67,
                    "entry_movement": "up",
                    "entry_change": 19,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "@bettingslip \u00a3100 league",
                    "short_name": null,
                    "created": "2017-07-18T14:28:55Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 116530,
                    "start_event": 1
                  },
                  {
                    "id": 230905,
                    "entry_rank": 158,
                    "entry_last_rank": 199,
                    "entry_movement": "up",
                    "entry_change": 41,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Opi's league - \u00a3150 prize pool",
                    "short_name": null,
                    "created": "2017-07-23T13:09:13Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 9881,
                    "start_event": 1
                  },
                  {
                    "id": 291211,
                    "entry_rank": 21,
                    "entry_last_rank": 25,
                    "entry_movement": "up",
                    "entry_change": 4,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Ime Property Ltd league",
                    "short_name": null,
                    "created": "2017-07-26T23:23:24Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1214941,
                    "start_event": 1
                  },
                  {
                    "id": 366152,
                    "entry_rank": 1,
                    "entry_last_rank": 1,
                    "entry_movement": "same",
                    "entry_change": null,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "'WolfPack'",
                    "short_name": null,
                    "created": "2017-07-31T17:40:53Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1529029,
                    "start_event": 1
                  },
                  {
                    "id": 490770,
                    "entry_rank": 4,
                    "entry_last_rank": 5,
                    "entry_movement": "up",
                    "entry_change": 1,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "Serie A Now ",
                    "short_name": null,
                    "created": "2017-08-05T18:12:51Z",
                    "closed": true,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 3700829,
                    "start_event": 1
                  },
                  {
                    "id": 743038,
                    "entry_rank": 1,
                    "entry_last_rank": 1,
                    "entry_movement": "same",
                    "entry_change": null,
                    "entry_can_leave": true,
                    "entry_can_admin": false,
                    "entry_can_invite": false,
                    "entry_can_forum": true,
                    "entry_code": null,
                    "name": "AJ's Angels",
                    "short_name": null,
                    "created": "2017-08-10T21:43:35Z",
                    "closed": false,
                    "forum_disabled": false,
                    "make_code_public": false,
                    "rank": null,
                    "size": null,
                    "league_type": "x",
                    "_scoring": "c",
                    "reprocess_standings": false,
                    "admin_entry": 1944860,
                    "start_event": 1
                  }
                ]
              },
              "season": [
                {
                  "id": 7408636,
                  "season_name": "2010\/11",
                  "total_points": 1726,
                  "rank": 923120,
                  "season": 5,
                  "player": 7425806
                },
                {
                  "id": 14217000,
                  "season_name": "2011\/12",
                  "total_points": 1706,
                  "rank": 1219063,
                  "season": 6,
                  "player": 7425806
                },
                {
                  "id": 19982494,
                  "season_name": "2012\/13",
                  "total_points": 1745,
                  "rank": 1243765,
                  "season": 7,
                  "player": 7425806
                },
                {
                  "id": 21729639,
                  "season_name": "2013\/14",
                  "total_points": 2019,
                  "rank": 965336,
                  "season": 8,
                  "player": 7425806
                },
                {
                  "id": 32730885,
                  "season_name": "2014\/15",
                  "total_points": 2016,
                  "rank": 174160,
                  "season": 9,
                  "player": 7425806
                },
                {
                  "id": 36051053,
                  "season_name": "2015\/16",
                  "total_points": 2212,
                  "rank": 32360,
                  "season": 10,
                  "player": 7425806
                },
                {
                  "id": 40342198,
                  "season_name": "2016\/17",
                  "total_points": 2146,
                  "rank": 140367,
                  "season": 11,
                  "player": 7425806
                }
              ],
              "history": [
                {
                  "id": 3523615,
                  "movement": "new",
                  "points": 73,
                  "total_points": 73,
                  "rank": 658447,
                  "rank_sort": 721973,
                  "overall_rank": 658447,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1000,
                  "points_on_bench": 5,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 1
                },
                {
                  "id": 7455715,
                  "movement": "down",
                  "points": 49,
                  "total_points": 118,
                  "rank": 1621606,
                  "rank_sort": 1633514,
                  "overall_rank": 924823,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 4,
                  "value": 1002,
                  "points_on_bench": 4,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 2
                },
                {
                  "id": 11977630,
                  "movement": "down",
                  "points": 40,
                  "total_points": 158,
                  "rank": 2776445,
                  "rank_sort": 2814131,
                  "overall_rank": 1168084,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1006,
                  "points_on_bench": 10,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 3
                },
                {
                  "id": 16696150,
                  "movement": "down",
                  "points": 39,
                  "total_points": 197,
                  "rank": 3228891,
                  "rank_sort": 3280126,
                  "overall_rank": 1476659,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1010,
                  "points_on_bench": 12,
                  "bank": 4,
                  "entry": 3523615,
                  "event": 4
                },
                {
                  "id": 21611275,
                  "movement": "up",
                  "points": 68,
                  "total_points": 265,
                  "rank": 1190358,
                  "rank_sort": 1227175,
                  "overall_rank": 1095805,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1014,
                  "points_on_bench": 13,
                  "bank": 4,
                  "entry": 3523615,
                  "event": 5
                },
                {
                  "id": 26657470,
                  "movement": "up",
                  "points": 77,
                  "total_points": 342,
                  "rank": 616536,
                  "rank_sort": 629459,
                  "overall_rank": 613827,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 0,
                  "value": 1018,
                  "points_on_bench": 12,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 6
                },
                {
                  "id": 31769200,
                  "movement": "down",
                  "points": 50,
                  "total_points": 392,
                  "rank": 2678047,
                  "rank_sort": 2705373,
                  "overall_rank": 739897,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1023,
                  "points_on_bench": 6,
                  "bank": 14,
                  "entry": 3523615,
                  "event": 7
                },
                {
                  "id": 36946465,
                  "movement": "down",
                  "points": 43,
                  "total_points": 431,
                  "rank": 2254969,
                  "rank_sort": 2275595,
                  "overall_rank": 895227,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 4,
                  "value": 1024,
                  "points_on_bench": 5,
                  "bank": 1,
                  "entry": 3523615,
                  "event": 8
                },
                {
                  "id": 42189265,
                  "movement": "up",
                  "points": 65,
                  "total_points": 496,
                  "rank": 865109,
                  "rank_sort": 878337,
                  "overall_rank": 587648,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1024,
                  "points_on_bench": 3,
                  "bank": 3,
                  "entry": 3523615,
                  "event": 9
                },
                {
                  "id": 47497600,
                  "movement": "up",
                  "points": 51,
                  "total_points": 547,
                  "rank": 1715351,
                  "rank_sort": 1737478,
                  "overall_rank": 505188,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1024,
                  "points_on_bench": 2,
                  "bank": 3,
                  "entry": 3523615,
                  "event": 10
                },
                {
                  "id": 52805935,
                  "movement": "up",
                  "points": 52,
                  "total_points": 599,
                  "rank": 1279225,
                  "rank_sort": 1324935,
                  "overall_rank": 404694,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1026,
                  "points_on_bench": 7,
                  "bank": 3,
                  "entry": 3523615,
                  "event": 11
                },
                {
                  "id": 58179805,
                  "movement": "down",
                  "points": 46,
                  "total_points": 645,
                  "rank": 4033889,
                  "rank_sort": 4043511,
                  "overall_rank": 683070,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 0,
                  "value": 1028,
                  "points_on_bench": 1,
                  "bank": 3,
                  "entry": 3523615,
                  "event": 12
                },
                {
                  "id": 63553675,
                  "movement": "up",
                  "points": 62,
                  "total_points": 707,
                  "rank": 200657,
                  "rank_sort": 208770,
                  "overall_rank": 422787,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1025,
                  "points_on_bench": 4,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 13
                },
                {
                  "id": 68993080,
                  "movement": "down",
                  "points": 52,
                  "total_points": 755,
                  "rank": 1903923,
                  "rank_sort": 1919907,
                  "overall_rank": 443090,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 4,
                  "value": 1025,
                  "points_on_bench": 2,
                  "bank": 2,
                  "entry": 3523615,
                  "event": 14
                },
                {
                  "id": 74432485,
                  "movement": "down",
                  "points": 39,
                  "total_points": 790,
                  "rank": 3649806,
                  "rank_sort": 3668074,
                  "overall_rank": 626723,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 4,
                  "value": 1030,
                  "points_on_bench": 4,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 15
                },
                {
                  "id": 79937425,
                  "movement": "up",
                  "points": 65,
                  "total_points": 855,
                  "rank": 293300,
                  "rank_sort": 308734,
                  "overall_rank": 403747,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1031,
                  "points_on_bench": 2,
                  "bank": 0,
                  "entry": 3523615,
                  "event": 16
                },
                {
                  "id": 85442365,
                  "movement": "up",
                  "points": 60,
                  "total_points": 915,
                  "rank": 871576,
                  "rank_sort": 881671,
                  "overall_rank": 288722,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 0,
                  "value": 1030,
                  "points_on_bench": 1,
                  "bank": 23,
                  "entry": 3523615,
                  "event": 17
                },
                {
                  "id": 90947305,
                  "movement": "down",
                  "points": 56,
                  "total_points": 971,
                  "rank": 2194419,
                  "rank_sort": 2215541,
                  "overall_rank": 310457,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1035,
                  "points_on_bench": 9,
                  "bank": 26,
                  "entry": 3523615,
                  "event": 18
                },
                {
                  "id": 96517780,
                  "movement": "up",
                  "points": 91,
                  "total_points": 1062,
                  "rank": 188106,
                  "rank_sort": 194690,
                  "overall_rank": 168113,
                  "targets": null,
                  "event_transfers": 1,
                  "event_transfers_cost": 0,
                  "value": 1039,
                  "points_on_bench": 10,
                  "bank": 26,
                  "entry": 3523615,
                  "event": 19
                },
                {
                  "id": 102088255,
                  "movement": "down",
                  "points": 75,
                  "total_points": 1137,
                  "rank": 1442332,
                  "rank_sort": 1476008,
                  "overall_rank": 177376,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1044,
                  "points_on_bench": 3,
                  "bank": 26,
                  "entry": 3523615,
                  "event": 20
                },
                {
                  "id": 107724265,
                  "movement": "up",
                  "points": 61,
                  "total_points": 1198,
                  "rank": 846836,
                  "rank_sort": 861437,
                  "overall_rank": 146986,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 0,
                  "value": 1048,
                  "points_on_bench": 0,
                  "bank": 11,
                  "entry": 3523615,
                  "event": 21
                },
                {
                  "id": 113360275,
                  "movement": "up",
                  "points": 57,
                  "total_points": 1251,
                  "rank": 1042702,
                  "rank_sort": 1053898,
                  "overall_rank": 136017,
                  "targets": null,
                  "event_transfers": 2,
                  "event_transfers_cost": 4,
                  "value": 1045,
                  "points_on_bench": 1,
                  "bank": 1,
                  "entry": 3523615,
                  "event": 22
                },
                {
                  "id": 118996285,
                  "movement": "up",
                  "points": 71,
                  "total_points": 1310,
                  "rank": 244725,
                  "rank_sort": 255775,
                  "overall_rank": 85421,
                  "targets": null,
                  "event_transfers": 0,
                  "event_transfers_cost": 0,
                  "value": 1051,
                  "points_on_bench": 2,
                  "bank": 1,
                  "entry": 3523615,
                  "event": 23
                }
              ]
            }
        """
        return requests.get("{}entry/{}/history".format(API_BASE_URL,
            user_id)).json()

    def user_picks(self, user_id, gameweek):
        """
        Returns a dictionary containing the picks of the user with the given
        `user_id` in the given gameweek.

        :param string user_id: A user's id
        :param int gameweek: The gameweek (1-38)

        Example output:

        .. code-block:: json

            {
              "entry_history": {
                "event": 20,
                "event_transfers_cost": 0,
                "points_on_bench": 3,
                "overall_rank": 177376,
                "rank": 1442332,
                "targets": null,
                "rank_sort": 1476008,
                "points": 75,
                "value": 1044,
                "total_points": 1137,
                "entry": 3523615,
                "event_transfers": 0,
                "id": 102088255,
                "bank": 26,
                "movement": "new"
              },
              "picks": [
                {
                  "position": 1,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 469
                },
                {
                  "position": 2,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 245
                },
                {
                  "position": 3,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 264
                },
                {
                  "position": 4,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 444
                },
                {
                  "position": 5,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 70
                },
                {
                  "position": 6,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 108
                },
                {
                  "position": 7,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 247
                },
                {
                  "position": 8,
                  "is_vice_captain": true,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 234
                },
                {
                  "position": 9,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 159
                },
                {
                  "position": 10,
                  "is_vice_captain": false,
                  "is_captain": true,
                  "multiplier": 2,
                  "element": 394
                },
                {
                  "position": 11,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 472
                },
                {
                  "position": 12,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 286
                },
                {
                  "position": 13,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 470
                },
                {
                  "position": 14,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 248
                },
                {
                  "position": 15,
                  "is_vice_captain": false,
                  "is_captain": false,
                  "multiplier": 1,
                  "element": 216
                }
              ],
              "active_chip": "",
              "event": {
                "is_previous": false,
                "deadline_time": "2017-12-26T11:30:00Z",
                "highest_scoring_entry": 3323943,
                "data_checked": true,
                "deadline_time_game_offset": 0,
                "deadline_time_epoch": 1514287800,
                "finished": true,
                "is_current": false,
                "highest_score": 154,
                "average_entry_score": 62,
                "deadline_time_formatted": "26 Dec 11:30",
                "is_next": false,
                "id": 20,
                "name": "Gameweek 20"
              },
              "automatic_subs": [
                {
                  "element_in": 159,
                  "entry": 3523615,
                  "id": 94935961,
                  "element_out": 470,
                  "event": 20
                },
                {
                  "element_in": 70,
                  "entry": 3523615,
                  "id": 94935962,
                  "element_out": 248,
                  "event": 20
                }
              ]
            }
        """
        return requests.get("{}entry/{}/event/{}/picks".format(API_BASE_URL,
            user_id, gameweek)).json()

    def user_cup(self, user_id):
        """
        Returns a dictionary with information about the cup progression of the
        user with the given `user_id`.

        :param string user_id: A user's id

        Example output:

        .. code-block:: json

            {
              "entry": {
                "summary_event_points": 71,
                "player_region_id": 152,
                "total_loans_active": 0,
                "player": 7425806,
                "player_first_name": "Amos",
                "event_transfers": 0,
                "strategy": null,
                "total_loans": 0,
                "joined_time": "2017-08-11T11:42:48Z",
                "event_transfers_cost": 0,
                "transfers_or_loans": "transfers",
                "favourite_team": 12,
                "id": 3523615,
                "player_region_name": "Netherlands",
                "summary_event_rank": 244725,
                "joined_seconds": 28625,
                "email": false,
                "extra_free_transfers": 1,
                "deleted": false,
                "kit": null,
                "player_region_short_iso": "NL",
                "summary_overall_points": 1310,
                "current_event": 23,
                "bank": 1,
                "started_event": 1,
                "name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                "total_transfers": 25,
                "summary_overall_rank": 85421,
                "value": 1051,
                "player_last_name": "Bastian"
              },
              "cup_status": {
                "qualification_numbers": 4194304,
                "qualification_state": "QUALIFIED",
                "qualification_rank": 293300,
                "qualification_event": 16
              },
              "cup_matches": [
                {
                  "tiebreak_used": false,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 60,
                  "entry_2_points": 43,
                  "event": 17,
                  "entry_2": 1548888,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1": 3523615,
                  "winning_entry": 3523615,
                  "id": 45233742,
                  "entry_2_player_name": "sherif gadallah",
                  "entry_2_name": "gandofly79"
                },
                {
                  "tiebreak_used": false,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 56,
                  "entry_2_points": 41,
                  "event": 18,
                  "entry_2": 4476163,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1": 3523615,
                  "winning_entry": 3523615,
                  "id": 47990644,
                  "entry_2_player_name": "EDWIN MUTHUI",
                  "entry_2_name": "DISASTER STRIKES FC"
                },
                {
                  "tiebreak_used": false,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 91,
                  "entry_2_points": 54,
                  "event": 19,
                  "entry_2": 1010689,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1": 3523615,
                  "winning_entry": 3523615,
                  "id": 48936155,
                  "entry_2_player_name": "stephen crozier",
                  "entry_2_name": "Pilot Light 2017"
                },
                {
                  "tiebreak_used": false,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 75,
                  "entry_2_points": 81,
                  "event": 20,
                  "entry_2": 3577330,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1": 3523615,
                  "winning_entry": 3577330,
                  "id": 49432119,
                  "entry_2_player_name": "craig johnston",
                  "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f"
                }
              ],
              "leagues": {
                "classic": [
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 12,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 15699,
                    "closed": false,
                    "entry_change": 9004,
                    "short_name": "team-12",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Man Utd",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:04Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 24703,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 172,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 261,
                    "closed": false,
                    "entry_change": 105,
                    "short_name": "region-152",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Netherlands",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 366,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 275,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 85073,
                    "closed": false,
                    "entry_change": 50022,
                    "short_name": "event-1",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Gameweek 1",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 135095,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 313,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 85421,
                    "closed": false,
                    "entry_change": 50596,
                    "short_name": "overall",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Overall",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 136017,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 583,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 2874,
                    "closed": false,
                    "entry_change": 913,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@FPL_Updates - \u00a3500 Prize",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:19:02Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1655,
                    "entry_last_rank": 3787,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 1849,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 420,
                    "closed": false,
                    "entry_change": 94,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@FPLSecrets \u00a310 monthly prize",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:36:28Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 5216,
                    "entry_last_rank": 514,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 1867,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 152,
                    "closed": false,
                    "entry_change": 47,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "\/r\/soccer",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:36:47Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 5324,
                    "entry_last_rank": 199,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 4204,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1940,
                    "closed": false,
                    "entry_change": 667,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Official \/r\/FantasyPL Classic League",
                    "entry_can_forum": true,
                    "created": "2017-07-12T11:02:54Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 2611,
                    "entry_last_rank": 2607,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 12110,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 32,
                    "closed": false,
                    "entry_change": 7,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "The Gift Experience - Win \u00a3100",
                    "entry_can_forum": true,
                    "created": "2017-07-12T12:30:24Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 40645,
                    "entry_last_rank": 39,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 45711,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 165,
                    "closed": true,
                    "entry_change": 59,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "WIN $3,000 of Dollarsandart",
                    "entry_can_forum": true,
                    "created": "2017-07-12T22:05:43Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 178060,
                    "entry_last_rank": 224,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 54728,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 75,
                    "closed": false,
                    "entry_change": 36,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "\/r\/reddevils",
                    "entry_can_forum": true,
                    "created": "2017-07-13T07:26:22Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 221213,
                    "entry_last_rank": 111,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 153984,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 64,
                    "closed": false,
                    "entry_change": 20,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Sean Graham Customer League ",
                    "entry_can_forum": true,
                    "created": "2017-07-18T09:04:08Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 647805,
                    "entry_last_rank": 84,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 159755,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 48,
                    "closed": false,
                    "entry_change": 19,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@bettingslip \u00a3100 league",
                    "entry_can_forum": true,
                    "created": "2017-07-18T14:28:55Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 116530,
                    "entry_last_rank": 67,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 230905,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 158,
                    "closed": false,
                    "entry_change": 41,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Opi's league - \u00a3150 prize pool",
                    "entry_can_forum": true,
                    "created": "2017-07-23T13:09:13Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 9881,
                    "entry_last_rank": 199,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 291211,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 21,
                    "closed": false,
                    "entry_change": 4,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Ime Property Ltd league",
                    "entry_can_forum": true,
                    "created": "2017-07-26T23:23:24Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1214941,
                    "entry_last_rank": 25,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 366152,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1,
                    "closed": false,
                    "entry_change": null,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "same",
                    "name": "'WolfPack'",
                    "entry_can_forum": true,
                    "created": "2017-07-31T17:40:53Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1529029,
                    "entry_last_rank": 1,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 490770,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 4,
                    "closed": true,
                    "entry_change": 1,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Serie A Now ",
                    "entry_can_forum": true,
                    "created": "2017-08-05T18:12:51Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 3700829,
                    "entry_last_rank": 5,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 743038,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1,
                    "closed": false,
                    "entry_change": null,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "same",
                    "name": "AJ's Angels",
                    "entry_can_forum": true,
                    "created": "2017-08-10T21:43:35Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1944860,
                    "entry_last_rank": 1,
                    "start_event": 1
                  }
                ],
                "h2h": [
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 314,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": null,
                    "closed": true,
                    "entry_change": null,
                    "short_name": "cup",
                    "_scoring": "h",
                    "entry_movement": null,
                    "name": "Cup",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "ko_rounds": 22,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "is_cup": true,
                    "entry_last_rank": null,
                    "start_event": 17
                  }
                ],
                "cup": [
                  {
                    "entry_2_draw": 0,
                    "entry_2_entry": 3577330,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_total": 0,
                    "entry_2_loss": 0,
                    "id": 49432119,
                    "tiebreak": null,
                    "entry_1_player_name": "Amos Bastian",
                    "entry_1_points": 75,
                    "entry_2_points": 81,
                    "winner": 3577330,
                    "event": 20,
                    "entry_2_win": 0,
                    "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f",
                    "entry_1_win": 0,
                    "entry_1_loss": 0,
                    "entry_2_player_name": "craig johnston",
                    "seed_value": null,
                    "is_knockout": true,
                    "entry_1_entry": 3523615,
                    "own_entry": false,
                    "entry_1_draw": 0,
                    "entry_2_total": 0
                  },
                  {
                    "entry_2_draw": 0,
                    "entry_2_entry": 1010689,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_total": 0,
                    "entry_2_loss": 0,
                    "id": 48936155,
                    "tiebreak": null,
                    "entry_1_player_name": "Amos Bastian",
                    "entry_1_points": 91,
                    "entry_2_points": 54,
                    "winner": 3523615,
                    "event": 19,
                    "entry_2_win": 0,
                    "entry_2_name": "Pilot Light 2017",
                    "entry_1_win": 0,
                    "entry_1_loss": 0,
                    "entry_2_player_name": "stephen crozier",
                    "seed_value": null,
                    "is_knockout": true,
                    "entry_1_entry": 3523615,
                    "own_entry": false,
                    "entry_1_draw": 0,
                    "entry_2_total": 0
                  }
                ]
              }
            }
        """
        return requests.get("{}entry/{}/cup".format(API_BASE_URL,
            user_id)).json()

    def user_transfers(self, user_id):
        """
        Returns a dictionary containing all transfers the user with the given 
        `user_id` has made.

        :param string user_id: A user's id

        Example output:

        .. code-block:: json

            {
              "wildcards": [
                {
                  "status": "played",
                  "name": "wildcard",
                  "chip": 1,
                  "time": "2017-08-28T00:07:04Z",
                  "entry": 3523615,
                  "played_time_formatted": "28 Aug 01:07",
                  "event": 4
                }
              ],
              "entry": {
                "summary_event_points": 71,
                "player_region_id": 152,
                "total_loans_active": 0,
                "player": 7425806,
                "player_first_name": "Amos",
                "event_transfers": 0,
                "strategy": null,
                "total_loans": 0,
                "joined_time": "2017-08-11T11:42:48Z",
                "event_transfers_cost": 0,
                "transfers_or_loans": "transfers",
                "favourite_team": 12,
                "id": 3523615,
                "player_region_name": "Netherlands",
                "summary_event_rank": 244725,
                "joined_seconds": 28666,
                "email": false,
                "extra_free_transfers": 1,
                "deleted": false,
                "kit": null,
                "player_region_short_iso": "NL",
                "summary_overall_points": 1310,
                "current_event": 23,
                "bank": 1,
                "started_event": 1,
                "name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                "total_transfers": 25,
                "summary_overall_rank": 85421,
                "value": 1051,
                "player_last_name": "Bastian"
              },
              "history": [
                {
                  "time": "2017-08-16T00:09:56Z",
                  "element_out": 268,
                  "event": 2,
                  "element_in": 171,
                  "element_in_cost": 45,
                  "time_formatted": "16 Aug 01:09",
                  "element_out_cost": 55,
                  "entry": 3523615,
                  "id": 3692137
                },
                {
                  "time": "2017-08-16T00:09:56Z",
                  "element_out": 126,
                  "event": 2,
                  "element_in": 281,
                  "element_in_cost": 80,
                  "time_formatted": "16 Aug 01:09",
                  "element_out_cost": 70,
                  "entry": 3523615,
                  "id": 3692138
                },
                {
                  "time": "2017-08-25T21:17:18Z",
                  "element_out": 223,
                  "event": 3,
                  "element_in": 402,
                  "element_in_cost": 45,
                  "time_formatted": "25 Aug 22:17",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 13375439
                },
                {
                  "time": "2017-08-26T23:59:14Z",
                  "element_out": 252,
                  "event": 4,
                  "element_in": 501,
                  "element_in_cost": 60,
                  "time_formatted": "27 Aug 00:59",
                  "element_out_cost": 100,
                  "entry": 3523615,
                  "id": 14855580
                },
                {
                  "time": "2017-08-28T00:07:04Z",
                  "element_out": 394,
                  "event": 4,
                  "element_in": 472,
                  "element_in_cost": 100,
                  "time_formatted": "28 Aug 01:07",
                  "element_out_cost": 125,
                  "entry": 3523615,
                  "id": 16102733
                },
                {
                  "time": "2017-09-04T00:06:02Z",
                  "element_out": 402,
                  "event": 4,
                  "element_in": 494,
                  "element_in_cost": 40,
                  "time_formatted": "04 Sep 01:06",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 18794172
                },
                {
                  "time": "2017-09-04T00:09:10Z",
                  "element_out": 80,
                  "event": 4,
                  "element_in": 198,
                  "element_in_cost": 51,
                  "time_formatted": "04 Sep 01:09",
                  "element_out_cost": 40,
                  "entry": 3523615,
                  "id": 18794410
                },
                {
                  "time": "2017-09-04T00:09:10Z",
                  "element_out": 60,
                  "event": 4,
                  "element_in": 264,
                  "element_in_cost": 51,
                  "time_formatted": "04 Sep 01:09",
                  "element_out_cost": 40,
                  "entry": 3523615,
                  "id": 18794411
                },
                {
                  "time": "2017-09-04T22:34:19Z",
                  "element_out": 320,
                  "event": 4,
                  "element_in": 234,
                  "element_in_cost": 90,
                  "time_formatted": "04 Sep 23:34",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 19021578
                },
                {
                  "time": "2017-09-09T01:40:13Z",
                  "element_out": 494,
                  "event": 4,
                  "element_in": 352,
                  "element_in_cost": 45,
                  "time_formatted": "09 Sep 02:40",
                  "element_out_cost": 40,
                  "entry": 3523615,
                  "id": 21489187
                },
                {
                  "time": "2017-09-09T01:40:13Z",
                  "element_out": 307,
                  "event": 4,
                  "element_in": 100,
                  "element_in_cost": 71,
                  "time_formatted": "09 Sep 02:40",
                  "element_out_cost": 55,
                  "entry": 3523615,
                  "id": 21489188
                },
                {
                  "time": "2017-09-09T01:40:13Z",
                  "element_out": 501,
                  "event": 4,
                  "element_in": 112,
                  "element_in_cost": 45,
                  "time_formatted": "09 Sep 02:40",
                  "element_out_cost": 60,
                  "entry": 3523615,
                  "id": 21489189
                },
                {
                  "time": "2017-09-09T01:40:13Z",
                  "element_out": 198,
                  "event": 4,
                  "element_in": 383,
                  "element_in_cost": 44,
                  "time_formatted": "09 Sep 02:40",
                  "element_out_cost": 51,
                  "entry": 3523615,
                  "id": 21489190
                },
                {
                  "time": "2017-09-18T23:18:56Z",
                  "element_out": 112,
                  "event": 6,
                  "element_in": 300,
                  "element_in_cost": 50,
                  "time_formatted": "19 Sep 00:18",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 33351023
                },
                {
                  "time": "2017-09-18T23:18:56Z",
                  "element_out": 235,
                  "event": 6,
                  "element_in": 209,
                  "element_in_cost": 85,
                  "time_formatted": "19 Sep 00:18",
                  "element_out_cost": 86,
                  "entry": 3523615,
                  "id": 33351024
                },
                {
                  "time": "2017-09-28T23:13:49Z",
                  "element_out": 100,
                  "event": 7,
                  "element_in": 381,
                  "element_in_cost": 57,
                  "time_formatted": "29 Sep 00:13",
                  "element_out_cost": 71,
                  "entry": 3523615,
                  "id": 42150126
                },
                {
                  "time": "2017-10-03T23:13:51Z",
                  "element_out": 387,
                  "event": 8,
                  "element_in": 248,
                  "element_in_cost": 84,
                  "time_formatted": "04 Oct 00:13",
                  "element_out_cost": 96,
                  "entry": 3523615,
                  "id": 48396188
                },
                {
                  "time": "2017-10-03T23:13:51Z",
                  "element_out": 472,
                  "event": 8,
                  "element_in": 394,
                  "element_in_cost": 127,
                  "time_formatted": "04 Oct 00:13",
                  "element_out_cost": 102,
                  "entry": 3523615,
                  "id": 48396189
                },
                {
                  "time": "2017-10-14T23:15:24Z",
                  "element_out": 281,
                  "event": 9,
                  "element_in": 247,
                  "element_in_cost": 80,
                  "time_formatted": "15 Oct 00:15",
                  "element_out_cost": 82,
                  "entry": 3523615,
                  "id": 53947101
                },
                {
                  "time": "2017-10-23T23:37:14Z",
                  "element_out": 285,
                  "event": 10,
                  "element_in": 257,
                  "element_in_cost": 116,
                  "time_formatted": "24 Oct 00:37",
                  "element_out_cost": 116,
                  "entry": 3523615,
                  "id": 61247741
                },
                {
                  "time": "2017-11-16T00:20:14Z",
                  "element_out": 421,
                  "event": 12,
                  "element_in": 469,
                  "element_in_cost": 45,
                  "time_formatted": "16 Nov 00:20",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 74072590
                },
                {
                  "time": "2017-11-18T00:44:31Z",
                  "element_out": 171,
                  "event": 12,
                  "element_in": 216,
                  "element_in_cost": 45,
                  "time_formatted": "18 Nov 00:44",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 75742987
                },
                {
                  "time": "2017-11-20T00:12:58Z",
                  "element_out": 352,
                  "event": 13,
                  "element_in": 34,
                  "element_in_cost": 48,
                  "time_formatted": "20 Nov 00:12",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 78233817
                },
                {
                  "time": "2017-11-27T00:24:52Z",
                  "element_out": 257,
                  "event": 14,
                  "element_in": 472,
                  "element_in_cost": 105,
                  "time_formatted": "27 Nov 00:24",
                  "element_out_cost": 116,
                  "entry": 3523615,
                  "id": 82958424
                },
                {
                  "time": "2017-11-27T00:24:52Z",
                  "element_out": 300,
                  "event": 14,
                  "element_in": 70,
                  "element_in_cost": 59,
                  "time_formatted": "27 Nov 00:24",
                  "element_out_cost": 50,
                  "entry": 3523615,
                  "id": 82958425
                },
                {
                  "time": "2017-11-29T00:31:36Z",
                  "element_out": 367,
                  "event": 15,
                  "element_in": 108,
                  "element_in_cost": 45,
                  "time_formatted": "29 Nov 00:31",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 85904458
                },
                {
                  "time": "2017-12-01T01:00:18Z",
                  "element_out": 264,
                  "event": 15,
                  "element_in": 470,
                  "element_in_cost": 54,
                  "time_formatted": "01 Dec 01:00",
                  "element_out_cost": 52,
                  "entry": 3523615,
                  "id": 87927959
                },
                {
                  "time": "2017-12-11T00:01:51Z",
                  "element_out": 209,
                  "event": 17,
                  "element_in": 159,
                  "element_in_cost": 52,
                  "time_formatted": "11 Dec 00:01",
                  "element_out_cost": 85,
                  "entry": 3523615,
                  "id": 96096595
                },
                {
                  "time": "2017-12-12T00:30:54Z",
                  "element_out": 34,
                  "event": 17,
                  "element_in": 245,
                  "element_in_cost": 59,
                  "time_formatted": "12 Dec 00:30",
                  "element_out_cost": 49,
                  "entry": 3523615,
                  "id": 97290645
                },
                {
                  "time": "2017-12-15T00:21:47Z",
                  "element_out": 381,
                  "event": 18,
                  "element_in": 264,
                  "element_in_cost": 53,
                  "time_formatted": "15 Dec 00:21",
                  "element_out_cost": 56,
                  "entry": 3523615,
                  "id": 101298525
                },
                {
                  "time": "2017-12-17T00:28:48Z",
                  "element_out": 383,
                  "event": 19,
                  "element_in": 444,
                  "element_in_cost": 43,
                  "time_formatted": "17 Dec 00:28",
                  "element_out_cost": 43,
                  "entry": 3523615,
                  "id": 104001923
                },
                {
                  "time": "2017-12-27T00:31:15Z",
                  "element_out": 108,
                  "event": 21,
                  "element_in": 279,
                  "element_in_cost": 60,
                  "time_formatted": "27 Dec 00:31",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 114287427
                },
                {
                  "time": "2017-12-27T00:31:15Z",
                  "element_out": 216,
                  "event": 21,
                  "element_in": 145,
                  "element_in_cost": 45,
                  "time_formatted": "27 Dec 00:31",
                  "element_out_cost": 45,
                  "entry": 3523615,
                  "id": 114287428
                },
                {
                  "time": "2018-01-01T10:39:45Z",
                  "element_out": 248,
                  "event": 22,
                  "element_in": 390,
                  "element_in_cost": 81,
                  "time_formatted": "01 Jan 10:39",
                  "element_out_cost": 81,
                  "entry": 3523615,
                  "id": 125519524
                },
                {
                  "time": "2018-01-01T10:39:45Z",
                  "element_out": 70,
                  "event": 22,
                  "element_in": 340,
                  "element_in_cost": 69,
                  "time_formatted": "01 Jan 10:39",
                  "element_out_cost": 59,
                  "entry": 3523615,
                  "id": 125519526
                }
              ],
              "leagues": {
                "classic": [
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 12,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 15699,
                    "closed": false,
                    "entry_change": 9004,
                    "short_name": "team-12",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Man Utd",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:04Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 24703,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 172,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 261,
                    "closed": false,
                    "entry_change": 105,
                    "short_name": "region-152",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Netherlands",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 366,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 275,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 85073,
                    "closed": false,
                    "entry_change": 50022,
                    "short_name": "event-1",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Gameweek 1",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 135095,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 313,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": 85421,
                    "closed": false,
                    "entry_change": 50596,
                    "short_name": "overall",
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Overall",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "entry_last_rank": 136017,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 583,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 2874,
                    "closed": false,
                    "entry_change": 913,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@FPL_Updates - \u00a3500 Prize",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:19:02Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1655,
                    "entry_last_rank": 3787,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 1849,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 420,
                    "closed": false,
                    "entry_change": 94,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@FPLSecrets \u00a310 monthly prize",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:36:28Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 5216,
                    "entry_last_rank": 514,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 1867,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 152,
                    "closed": false,
                    "entry_change": 47,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "\/r\/soccer",
                    "entry_can_forum": true,
                    "created": "2017-07-12T10:36:47Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 5324,
                    "entry_last_rank": 199,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 4204,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1940,
                    "closed": false,
                    "entry_change": 667,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Official \/r\/FantasyPL Classic League",
                    "entry_can_forum": true,
                    "created": "2017-07-12T11:02:54Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 2611,
                    "entry_last_rank": 2607,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 12110,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 32,
                    "closed": false,
                    "entry_change": 7,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "The Gift Experience - Win \u00a3100",
                    "entry_can_forum": true,
                    "created": "2017-07-12T12:30:24Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 40645,
                    "entry_last_rank": 39,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 45711,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 165,
                    "closed": true,
                    "entry_change": 59,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "WIN $3,000 of Dollarsandart",
                    "entry_can_forum": true,
                    "created": "2017-07-12T22:05:43Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 178060,
                    "entry_last_rank": 224,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 54728,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 75,
                    "closed": false,
                    "entry_change": 36,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "\/r\/reddevils",
                    "entry_can_forum": true,
                    "created": "2017-07-13T07:26:22Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 221213,
                    "entry_last_rank": 111,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 153984,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 64,
                    "closed": false,
                    "entry_change": 20,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Sean Graham Customer League ",
                    "entry_can_forum": true,
                    "created": "2017-07-18T09:04:08Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 647805,
                    "entry_last_rank": 84,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 159755,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 48,
                    "closed": false,
                    "entry_change": 19,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "@bettingslip \u00a3100 league",
                    "entry_can_forum": true,
                    "created": "2017-07-18T14:28:55Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 116530,
                    "entry_last_rank": 67,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 230905,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 158,
                    "closed": false,
                    "entry_change": 41,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Opi's league - \u00a3150 prize pool",
                    "entry_can_forum": true,
                    "created": "2017-07-23T13:09:13Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 9881,
                    "entry_last_rank": 199,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 291211,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 21,
                    "closed": false,
                    "entry_change": 4,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Ime Property Ltd league",
                    "entry_can_forum": true,
                    "created": "2017-07-26T23:23:24Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1214941,
                    "entry_last_rank": 25,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 366152,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1,
                    "closed": false,
                    "entry_change": null,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "same",
                    "name": "'WolfPack'",
                    "entry_can_forum": true,
                    "created": "2017-07-31T17:40:53Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1529029,
                    "entry_last_rank": 1,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 490770,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 4,
                    "closed": true,
                    "entry_change": 1,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "up",
                    "name": "Serie A Now ",
                    "entry_can_forum": true,
                    "created": "2017-08-05T18:12:51Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 3700829,
                    "entry_last_rank": 5,
                    "start_event": 1
                  },
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 743038,
                    "size": null,
                    "league_type": "x",
                    "entry_can_leave": true,
                    "forum_disabled": false,
                    "entry_rank": 1,
                    "closed": false,
                    "entry_change": null,
                    "short_name": null,
                    "reprocess_standings": false,
                    "_scoring": "c",
                    "entry_movement": "same",
                    "name": "AJ's Angels",
                    "entry_can_forum": true,
                    "created": "2017-08-10T21:43:35Z",
                    "entry_can_invite": false,
                    "entry_can_admin": false,
                    "admin_entry": 1944860,
                    "entry_last_rank": 1,
                    "start_event": 1
                  }
                ],
                "h2h": [
                  {
                    "rank": null,
                    "entry_code": null,
                    "make_code_public": false,
                    "id": 314,
                    "size": null,
                    "league_type": "s",
                    "entry_can_leave": false,
                    "forum_disabled": false,
                    "entry_rank": null,
                    "closed": true,
                    "entry_change": null,
                    "short_name": "cup",
                    "_scoring": "h",
                    "entry_movement": null,
                    "name": "Cup",
                    "entry_can_forum": false,
                    "created": "2017-07-12T09:49:05Z",
                    "entry_can_invite": false,
                    "ko_rounds": 22,
                    "entry_can_admin": false,
                    "admin_entry": null,
                    "is_cup": true,
                    "entry_last_rank": null,
                    "start_event": 17
                  }
                ],
                "cup": [
                  {
                    "entry_2_draw": 0,
                    "entry_2_entry": 3577330,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_total": 0,
                    "entry_2_loss": 0,
                    "id": 49432119,
                    "tiebreak": null,
                    "entry_1_player_name": "Amos Bastian",
                    "entry_1_points": 75,
                    "entry_2_points": 81,
                    "winner": 3577330,
                    "event": 20,
                    "entry_2_win": 0,
                    "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f",
                    "entry_1_win": 0,
                    "entry_1_loss": 0,
                    "entry_2_player_name": "craig johnston",
                    "seed_value": null,
                    "is_knockout": true,
                    "entry_1_entry": 3523615,
                    "own_entry": false,
                    "entry_1_draw": 0,
                    "entry_2_total": 0
                  },
                  {
                    "entry_2_draw": 0,
                    "entry_2_entry": 1010689,
                    "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                    "entry_1_total": 0,
                    "entry_2_loss": 0,
                    "id": 48936155,
                    "tiebreak": null,
                    "entry_1_player_name": "Amos Bastian",
                    "entry_1_points": 91,
                    "entry_2_points": 54,
                    "winner": 3523615,
                    "event": 19,
                    "entry_2_win": 0,
                    "entry_2_name": "Pilot Light 2017",
                    "entry_1_win": 0,
                    "entry_1_loss": 0,
                    "entry_2_player_name": "stephen crozier",
                    "seed_value": null,
                    "is_knockout": true,
                    "entry_1_entry": 3523615,
                    "own_entry": false,
                    "entry_1_draw": 0,
                    "entry_2_total": 0
                  }
                ]
              }
            }
        """
        return requests.get("{}entry/{}/transfers".format(API_BASE_URL,
            user_id)).json()

    def user_leagues_entered(self, user_id):
        """
        Returns a dictionary with information about all leagues that the user 
        with the given `user_id` is currently participating in.

        :param string user_id: A user's id

        Example output:

        .. code-block:: json

            {
              "classic": [
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 12,
                  "size": null,
                  "league_type": "s",
                  "entry_can_leave": false,
                  "forum_disabled": false,
                  "entry_rank": 15699,
                  "closed": false,
                  "entry_change": 9004,
                  "short_name": "team-12",
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Man Utd",
                  "entry_can_forum": false,
                  "created": "2017-07-12T09:49:04Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": null,
                  "entry_last_rank": 24703,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 172,
                  "size": null,
                  "league_type": "s",
                  "entry_can_leave": false,
                  "forum_disabled": false,
                  "entry_rank": 261,
                  "closed": false,
                  "entry_change": 105,
                  "short_name": "region-152",
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Netherlands",
                  "entry_can_forum": false,
                  "created": "2017-07-12T09:49:05Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": null,
                  "entry_last_rank": 366,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 275,
                  "size": null,
                  "league_type": "s",
                  "entry_can_leave": false,
                  "forum_disabled": false,
                  "entry_rank": 85073,
                  "closed": false,
                  "entry_change": 50022,
                  "short_name": "event-1",
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Gameweek 1",
                  "entry_can_forum": false,
                  "created": "2017-07-12T09:49:05Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": null,
                  "entry_last_rank": 135095,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 313,
                  "size": null,
                  "league_type": "s",
                  "entry_can_leave": false,
                  "forum_disabled": false,
                  "entry_rank": 85421,
                  "closed": false,
                  "entry_change": 50596,
                  "short_name": "overall",
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Overall",
                  "entry_can_forum": false,
                  "created": "2017-07-12T09:49:05Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": null,
                  "entry_last_rank": 136017,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 583,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 2874,
                  "closed": false,
                  "entry_change": 913,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "@FPL_Updates - \u00a3500 Prize",
                  "entry_can_forum": true,
                  "created": "2017-07-12T10:19:02Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 1655,
                  "entry_last_rank": 3787,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 1849,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 420,
                  "closed": false,
                  "entry_change": 94,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "@FPLSecrets \u00a310 monthly prize",
                  "entry_can_forum": true,
                  "created": "2017-07-12T10:36:28Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 5216,
                  "entry_last_rank": 514,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 1867,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 152,
                  "closed": false,
                  "entry_change": 47,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "\/r\/soccer",
                  "entry_can_forum": true,
                  "created": "2017-07-12T10:36:47Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 5324,
                  "entry_last_rank": 199,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 4204,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 1940,
                  "closed": false,
                  "entry_change": 667,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Official \/r\/FantasyPL Classic League",
                  "entry_can_forum": true,
                  "created": "2017-07-12T11:02:54Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 2611,
                  "entry_last_rank": 2607,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 12110,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 32,
                  "closed": false,
                  "entry_change": 7,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "The Gift Experience - Win \u00a3100",
                  "entry_can_forum": true,
                  "created": "2017-07-12T12:30:24Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 40645,
                  "entry_last_rank": 39,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 45711,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 165,
                  "closed": true,
                  "entry_change": 59,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "WIN $3,000 of Dollarsandart",
                  "entry_can_forum": true,
                  "created": "2017-07-12T22:05:43Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 178060,
                  "entry_last_rank": 224,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 54728,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 75,
                  "closed": false,
                  "entry_change": 36,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "\/r\/reddevils",
                  "entry_can_forum": true,
                  "created": "2017-07-13T07:26:22Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 221213,
                  "entry_last_rank": 111,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 153984,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 64,
                  "closed": false,
                  "entry_change": 20,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Sean Graham Customer League ",
                  "entry_can_forum": true,
                  "created": "2017-07-18T09:04:08Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 647805,
                  "entry_last_rank": 84,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 159755,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 48,
                  "closed": false,
                  "entry_change": 19,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "@bettingslip \u00a3100 league",
                  "entry_can_forum": true,
                  "created": "2017-07-18T14:28:55Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 116530,
                  "entry_last_rank": 67,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 230905,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 158,
                  "closed": false,
                  "entry_change": 41,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Opi's league - \u00a3150 prize pool",
                  "entry_can_forum": true,
                  "created": "2017-07-23T13:09:13Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 9881,
                  "entry_last_rank": 199,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 291211,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 21,
                  "closed": false,
                  "entry_change": 4,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Ime Property Ltd league",
                  "entry_can_forum": true,
                  "created": "2017-07-26T23:23:24Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 1214941,
                  "entry_last_rank": 25,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 366152,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 1,
                  "closed": false,
                  "entry_change": null,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "same",
                  "name": "'WolfPack'",
                  "entry_can_forum": true,
                  "created": "2017-07-31T17:40:53Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 1529029,
                  "entry_last_rank": 1,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 490770,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 4,
                  "closed": true,
                  "entry_change": 1,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "up",
                  "name": "Serie A Now ",
                  "entry_can_forum": true,
                  "created": "2017-08-05T18:12:51Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 3700829,
                  "entry_last_rank": 5,
                  "start_event": 1
                },
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 743038,
                  "size": null,
                  "league_type": "x",
                  "entry_can_leave": true,
                  "forum_disabled": false,
                  "entry_rank": 1,
                  "closed": false,
                  "entry_change": null,
                  "short_name": null,
                  "reprocess_standings": false,
                  "_scoring": "c",
                  "entry_movement": "same",
                  "name": "AJ's Angels",
                  "entry_can_forum": true,
                  "created": "2017-08-10T21:43:35Z",
                  "entry_can_invite": false,
                  "entry_can_admin": false,
                  "admin_entry": 1944860,
                  "entry_last_rank": 1,
                  "start_event": 1
                }
              ],
              "h2h": [
                {
                  "rank": null,
                  "entry_code": null,
                  "make_code_public": false,
                  "id": 314,
                  "size": null,
                  "league_type": "s",
                  "entry_can_leave": false,
                  "forum_disabled": false,
                  "entry_rank": null,
                  "closed": true,
                  "entry_change": null,
                  "short_name": "cup",
                  "_scoring": "h",
                  "entry_movement": null,
                  "name": "Cup",
                  "entry_can_forum": false,
                  "created": "2017-07-12T09:49:05Z",
                  "entry_can_invite": false,
                  "ko_rounds": 22,
                  "entry_can_admin": false,
                  "admin_entry": null,
                  "is_cup": true,
                  "entry_last_rank": null,
                  "start_event": 17
                }
              ],
              "cup": [
                {
                  "entry_2_draw": 0,
                  "entry_2_entry": 3577330,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1_total": 0,
                  "entry_2_loss": 0,
                  "id": 49432119,
                  "tiebreak": null,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 75,
                  "entry_2_points": 81,
                  "winner": 3577330,
                  "event": 20,
                  "entry_2_win": 0,
                  "entry_2_name": "Coventry City \ufffd\u26aa\ufe0f",
                  "entry_1_win": 0,
                  "entry_1_loss": 0,
                  "entry_2_player_name": "craig johnston",
                  "seed_value": null,
                  "is_knockout": true,
                  "entry_1_entry": 3523615,
                  "own_entry": false,
                  "entry_1_draw": 0,
                  "entry_2_total": 0
                },
                {
                  "entry_2_draw": 0,
                  "entry_2_entry": 1010689,
                  "entry_1_name": "( \u0361\u00b0 \u035c\u0296 \u0361\u00b0)",
                  "entry_1_total": 0,
                  "entry_2_loss": 0,
                  "id": 48936155,
                  "tiebreak": null,
                  "entry_1_player_name": "Amos Bastian",
                  "entry_1_points": 91,
                  "entry_2_points": 54,
                  "winner": 3523615,
                  "event": 19,
                  "entry_2_win": 0,
                  "entry_2_name": "Pilot Light 2017",
                  "entry_1_win": 0,
                  "entry_1_loss": 0,
                  "entry_2_player_name": "stephen crozier",
                  "seed_value": null,
                  "is_knockout": true,
                  "entry_1_entry": 3523615,
                  "own_entry": false,
                  "entry_1_draw": 0,
                  "entry_2_total": 0
                }
              ]
            }
        """
        return requests.get("{}leagues-entered/{}".format(API_BASE_URL,
            user_id)).json()

    @property
    def teams(self):
        """
        Returns a list of information about all teams currently participating 
        in the Premier League.
        """
        return requests.get("{}teams".format(API_BASE_URL)).json()

    @property
    def players(self):
        """
        Returns a list of information about all players currently playing for 
        teams in the Premier League.
        """
        return requests.get("{}elements".format(API_BASE_URL)).json()

    def player(self, player_id):
        """
        Returns a dictionary containing information about the player with the 
        given `player_id`.

        :param int player_id: A player's id

        Example output:

        .. code-block:: json

            {
              "history_past": [
                {
                  "yellow_cards": 0,
                  "goals_conceded": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "goals_scored": 0,
                  "id": 3826,
                  "own_goals": 0,
                  "creativity": "0.0",
                  "end_cost": 55,
                  "ict_index": "0.0",
                  "season": 6,
                  "total_points": 3,
                  "penalties_missed": 0,
                  "start_cost": 55,
                  "element_code": 74208,
                  "bonus": 0,
                  "season_name": "2011\/12",
                  "clean_sheets": 0,
                  "assists": 0,
                  "ea_index": 5,
                  "penalties_saved": 0,
                  "minutes": 71,
                  "bps": 0,
                  "threat": "0.0",
                  "red_cards": 0
                },
                {
                  "yellow_cards": 7,
                  "goals_conceded": 21,
                  "saves": 0,
                  "influence": "713.0",
                  "goals_scored": 5,
                  "id": 7322,
                  "own_goals": 0,
                  "creativity": "953.5",
                  "end_cost": 82,
                  "ict_index": "250.0",
                  "season": 11,
                  "total_points": 115,
                  "penalties_missed": 0,
                  "start_cost": 85,
                  "element_code": 74208,
                  "bonus": 14,
                  "season_name": "2016\/17",
                  "clean_sheets": 13,
                  "assists": 4,
                  "ea_index": 0,
                  "penalties_saved": 0,
                  "minutes": 2608,
                  "bps": 512,
                  "threat": "839.0",
                  "red_cards": 0
                }
              ],
              "fixtures_summary": [
                {
                  "opponent_name": "Stoke",
                  "code": 919118,
                  "difficulty": 2,
                  "event_name": "Gameweek 23",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 23,
                  "kickoff_time_formatted": "15 Jan 20:00",
                  "opponent_short_name": "STK",
                  "finished": false,
                  "kickoff_time": "2018-01-15T20:00:00Z",
                  "team_a_score": null,
                  "team_a": 15,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 226,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Burnley",
                  "code": 919125,
                  "difficulty": 3,
                  "event_name": "Gameweek 24",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 24,
                  "kickoff_time_formatted": "20 Jan 15:00",
                  "opponent_short_name": "BUR",
                  "finished": false,
                  "kickoff_time": "2018-01-20T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 233,
                  "provisional_start_time": false,
                  "team_h": 4
                },
                {
                  "opponent_name": "Spurs",
                  "code": 919142,
                  "difficulty": 4,
                  "event_name": "Gameweek 25",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 25,
                  "kickoff_time_formatted": "31 Jan 20:00",
                  "opponent_short_name": "TOT",
                  "finished": false,
                  "kickoff_time": "2018-01-31T20:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 250,
                  "provisional_start_time": false,
                  "team_h": 17
                }
              ],
              "explain": [
                {
                  "explain": {
                    "minutes": {
                      "points": 0,
                      "name": "Minutes played",
                      "value": 0
                    }
                  },
                  "fixture": {
                    "code": 919118,
                    "stats": [
                      
                    ],
                    "deadline_time": "2018-01-13T14:00:00Z",
                    "deadline_time_formatted": "13 Jan 14:00",
                    "started": false,
                    "team_h_score": null,
                    "event": 23,
                    "kickoff_time_formatted": "15 Jan 20:00",
                    "finished": false,
                    "kickoff_time": "2018-01-15T20:00:00Z",
                    "team_a_score": null,
                    "team_a": 15,
                    "event_day": 3,
                    "finished_provisional": false,
                    "minutes": 0,
                    "id": 226,
                    "provisional_start_time": false,
                    "team_h": 12
                  }
                }
              ],
              "history_summary": [
                {
                  "transfers_out": 46503,
                  "yellow_cards": 0,
                  "tackles": 1,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "9.2",
                  "key_passes": 0,
                  "transfers_in": 34953,
                  "transfers_balance": -11550,
                  "goals_scored": 0,
                  "id": 11469,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 690653,
                  "creativity": "5.8",
                  "kickoff_time_formatted": "30 Dec 17:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "2.3",
                  "total_points": 3,
                  "penalties_missed": 0,
                  "attempted_passes": 62,
                  "opponent_team": 14,
                  "completed_passes": 55,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 206,
                  "was_home": true,
                  "recoveries": 4,
                  "clean_sheets": 1,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 2,
                  "penalties_conceded": 0,
                  "offside": 1,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-30T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 1,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 11,
                  "dribbles": 1,
                  "threat": "8.0",
                  "tackled": 2,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 21
                },
                {
                  "transfers_out": 73053,
                  "yellow_cards": 0,
                  "tackles": 1,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "51.2",
                  "key_passes": 5,
                  "transfers_in": 14621,
                  "transfers_balance": -58432,
                  "goals_scored": 0,
                  "id": 11995,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 633117,
                  "creativity": "57.4",
                  "kickoff_time_formatted": "01 Jan 17:30",
                  "bonus": 3,
                  "big_chances_created": 0,
                  "ict_index": "16.1",
                  "total_points": 12,
                  "penalties_missed": 0,
                  "attempted_passes": 61,
                  "opponent_team": 7,
                  "completed_passes": 51,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 214,
                  "was_home": false,
                  "recoveries": 7,
                  "clean_sheets": 1,
                  "assists": 2,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 3,
                  "penalties_conceded": 0,
                  "offside": 1,
                  "ea_index": 0,
                  "kickoff_time": "2018-01-01T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 2,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 32,
                  "dribbles": 2,
                  "threat": "52.0",
                  "tackled": 1,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 22
                },
                {
                  "transfers_out": 32998,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 172650,
                  "transfers_balance": 139652,
                  "goals_scored": 0,
                  "id": 12647,
                  "own_goals": 0,
                  "team_h_score": null,
                  "selected": 780062,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "15 Jan 20:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 15,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 226,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": null,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2018-01-15T20:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 23
                }
              ],
              "fixtures": [
                {
                  "opponent_name": "Stoke",
                  "code": 919118,
                  "difficulty": 2,
                  "event_name": "Gameweek 23",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 23,
                  "kickoff_time_formatted": "15 Jan 20:00",
                  "opponent_short_name": "STK",
                  "finished": false,
                  "kickoff_time": "2018-01-15T20:00:00Z",
                  "team_a_score": null,
                  "team_a": 15,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 226,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Burnley",
                  "code": 919125,
                  "difficulty": 3,
                  "event_name": "Gameweek 24",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 24,
                  "kickoff_time_formatted": "20 Jan 15:00",
                  "opponent_short_name": "BUR",
                  "finished": false,
                  "kickoff_time": "2018-01-20T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 233,
                  "provisional_start_time": false,
                  "team_h": 4
                },
                {
                  "opponent_name": "Spurs",
                  "code": 919142,
                  "difficulty": 4,
                  "event_name": "Gameweek 25",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 25,
                  "kickoff_time_formatted": "31 Jan 20:00",
                  "opponent_short_name": "TOT",
                  "finished": false,
                  "kickoff_time": "2018-01-31T20:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 250,
                  "provisional_start_time": false,
                  "team_h": 17
                },
                {
                  "opponent_name": "Huddersfield",
                  "code": 919150,
                  "difficulty": 2,
                  "event_name": "Gameweek 26",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 26,
                  "kickoff_time_formatted": "03 Feb 15:00",
                  "opponent_short_name": "HUD",
                  "finished": false,
                  "kickoff_time": "2018-02-03T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 8,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 258,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Newcastle",
                  "code": 919157,
                  "difficulty": 2,
                  "event_name": "Gameweek 27",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 27,
                  "kickoff_time_formatted": "11 Feb 14:15",
                  "opponent_short_name": "NEW",
                  "finished": false,
                  "kickoff_time": "2018-02-11T14:15:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 265,
                  "provisional_start_time": false,
                  "team_h": 13
                },
                {
                  "opponent_name": "Chelsea",
                  "code": 919170,
                  "difficulty": 4,
                  "event_name": "Gameweek 28",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 28,
                  "kickoff_time_formatted": "25 Feb 14:05",
                  "opponent_short_name": "CHE",
                  "finished": false,
                  "kickoff_time": "2018-02-25T14:05:00Z",
                  "team_a_score": null,
                  "team_a": 5,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 278,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Crystal Palace",
                  "code": 919175,
                  "difficulty": 2,
                  "event_name": "Gameweek 29",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 29,
                  "kickoff_time_formatted": "03 Mar 15:00",
                  "opponent_short_name": "CRY",
                  "finished": false,
                  "kickoff_time": "2018-03-03T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 283,
                  "provisional_start_time": false,
                  "team_h": 6
                },
                {
                  "opponent_name": "Liverpool",
                  "code": 919188,
                  "difficulty": 4,
                  "event_name": "Gameweek 30",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 30,
                  "kickoff_time_formatted": "10 Mar 15:00",
                  "opponent_short_name": "LIV",
                  "finished": false,
                  "kickoff_time": "2018-03-10T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 10,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 296,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "West Ham",
                  "code": 919202,
                  "difficulty": 2,
                  "event_name": "Gameweek 31",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 31,
                  "kickoff_time_formatted": "17 Mar 15:00",
                  "opponent_short_name": "WHU",
                  "finished": false,
                  "kickoff_time": "2018-03-17T15:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 310,
                  "provisional_start_time": false,
                  "team_h": 20
                },
                {
                  "opponent_name": "Swansea",
                  "code": 919208,
                  "difficulty": 2,
                  "event_name": "Gameweek 32",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 32,
                  "kickoff_time_formatted": "31 Mar 15:00",
                  "opponent_short_name": "SWA",
                  "finished": false,
                  "kickoff_time": "2018-03-31T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 16,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 316,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Man City",
                  "code": 919219,
                  "difficulty": 5,
                  "event_name": "Gameweek 33",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 33,
                  "kickoff_time_formatted": "07 Apr 15:00",
                  "opponent_short_name": "MCI",
                  "finished": false,
                  "kickoff_time": "2018-04-07T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 327,
                  "provisional_start_time": false,
                  "team_h": 11
                },
                {
                  "opponent_name": "West Brom",
                  "code": 919227,
                  "difficulty": 2,
                  "event_name": "Gameweek 34",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 34,
                  "kickoff_time_formatted": "14 Apr 15:00",
                  "opponent_short_name": "WBA",
                  "finished": false,
                  "kickoff_time": "2018-04-14T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 19,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 335,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Bournemouth",
                  "code": 919233,
                  "difficulty": 2,
                  "event_name": "Gameweek 35",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 35,
                  "kickoff_time_formatted": "21 Apr 15:00",
                  "opponent_short_name": "BOU",
                  "finished": false,
                  "kickoff_time": "2018-04-21T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 342,
                  "provisional_start_time": false,
                  "team_h": 2
                },
                {
                  "opponent_name": "Arsenal",
                  "code": 919247,
                  "difficulty": 4,
                  "event_name": "Gameweek 36",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 36,
                  "kickoff_time_formatted": "28 Apr 15:00",
                  "opponent_short_name": "ARS",
                  "finished": false,
                  "kickoff_time": "2018-04-28T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 1,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 355,
                  "provisional_start_time": false,
                  "team_h": 12
                },
                {
                  "opponent_name": "Brighton",
                  "code": 919255,
                  "difficulty": 2,
                  "event_name": "Gameweek 37",
                  "team_h_score": null,
                  "is_home": false,
                  "event": 37,
                  "kickoff_time_formatted": "05 May 15:00",
                  "opponent_short_name": "BHA",
                  "finished": false,
                  "kickoff_time": "2018-05-05T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 12,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 363,
                  "provisional_start_time": false,
                  "team_h": 3
                },
                {
                  "opponent_name": "Watford",
                  "code": 919267,
                  "difficulty": 2,
                  "event_name": "Gameweek 38",
                  "team_h_score": null,
                  "is_home": true,
                  "event": 38,
                  "kickoff_time_formatted": "13 May 15:00",
                  "opponent_short_name": "WAT",
                  "finished": false,
                  "kickoff_time": "2018-05-13T14:00:00Z",
                  "team_a_score": null,
                  "team_a": 18,
                  "finished_provisional": false,
                  "minutes": 0,
                  "id": 375,
                  "provisional_start_time": false,
                  "team_h": 12
                }
              ],
              "history": [
                {
                  "transfers_out": 0,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "48.2",
                  "key_passes": 2,
                  "transfers_in": 0,
                  "transfers_balance": 0,
                  "goals_scored": 1,
                  "id": 282,
                  "own_goals": 0,
                  "team_h_score": 4,
                  "selected": 812407,
                  "creativity": "40.3",
                  "kickoff_time_formatted": "13 Aug 16:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "13.6",
                  "total_points": 8,
                  "penalties_missed": 0,
                  "attempted_passes": 62,
                  "opponent_team": 20,
                  "completed_passes": 54,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 9,
                  "was_home": true,
                  "recoveries": 6,
                  "clean_sheets": 1,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 2,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-08-13T15:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 4,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 31,
                  "dribbles": 6,
                  "threat": "47.0",
                  "tackled": 4,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 1
                },
                {
                  "transfers_out": 27834,
                  "yellow_cards": 1,
                  "tackles": 3,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "65.6",
                  "key_passes": 3,
                  "transfers_in": 111989,
                  "transfers_balance": 84155,
                  "goals_scored": 1,
                  "id": 793,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 1056883,
                  "creativity": "38.1",
                  "kickoff_time_formatted": "19 Aug 12:30",
                  "bonus": 2,
                  "big_chances_created": 0,
                  "ict_index": "14.5",
                  "total_points": 15,
                  "penalties_missed": 0,
                  "attempted_passes": 75,
                  "opponent_team": 16,
                  "completed_passes": 61,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 17,
                  "was_home": false,
                  "recoveries": 4,
                  "clean_sheets": 1,
                  "assists": 2,
                  "team_a_score": 4,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 2,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-08-19T11:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 3,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 45,
                  "dribbles": 2,
                  "threat": "41.0",
                  "tackled": 4,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 2
                },
                {
                  "transfers_out": 20293,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "4.0",
                  "key_passes": 1,
                  "transfers_in": 465190,
                  "transfers_balance": 444897,
                  "goals_scored": 0,
                  "id": 1309,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 1621268,
                  "creativity": "27.4",
                  "kickoff_time_formatted": "26 Aug 17:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "5.5",
                  "total_points": 3,
                  "penalties_missed": 0,
                  "attempted_passes": 106,
                  "opponent_team": 9,
                  "completed_passes": 93,
                  "target_missed": 5,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 25,
                  "was_home": true,
                  "recoveries": 6,
                  "clean_sheets": 1,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 1,
                  "penalties_conceded": 0,
                  "offside": 1,
                  "ea_index": 0,
                  "kickoff_time": "2017-08-26T16:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 82,
                  "element": 282,
                  "bps": 2,
                  "dribbles": 4,
                  "threat": "24.0",
                  "tackled": 6,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 3
                },
                {
                  "transfers_out": 53179,
                  "yellow_cards": 0,
                  "tackles": 1,
                  "goals_conceded": 2,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "31.6",
                  "key_passes": 3,
                  "transfers_in": 183515,
                  "transfers_balance": 130336,
                  "goals_scored": 0,
                  "id": 1840,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 1833726,
                  "creativity": "39.0",
                  "kickoff_time_formatted": "09 Sep 17:30",
                  "bonus": 0,
                  "big_chances_created": 1,
                  "ict_index": "14.5",
                  "total_points": 5,
                  "penalties_missed": 0,
                  "attempted_passes": 67,
                  "opponent_team": 15,
                  "completed_passes": 56,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 37,
                  "was_home": false,
                  "recoveries": 4,
                  "clean_sheets": 0,
                  "assists": 1,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-09-09T16:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 4,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 83,
                  "element": 282,
                  "bps": 22,
                  "dribbles": 2,
                  "threat": "74.0",
                  "tackled": 0,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 4
                },
                {
                  "transfers_out": 615508,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 83781,
                  "transfers_balance": -531727,
                  "goals_scored": 0,
                  "id": 2384,
                  "own_goals": 0,
                  "team_h_score": 4,
                  "selected": 1323399,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "17 Sep 16:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 7,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 50,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-09-17T15:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 82,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 5
                },
                {
                  "transfers_out": 563045,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 2692,
                  "transfers_balance": -560353,
                  "goals_scored": 0,
                  "id": 2930,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 765452,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "23 Sep 15:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 14,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 55,
                  "was_home": false,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 1,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-09-23T14:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 81,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 6
                },
                {
                  "transfers_out": 187385,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 1026,
                  "transfers_balance": -186359,
                  "goals_scored": 0,
                  "id": 3480,
                  "own_goals": 0,
                  "team_h_score": 4,
                  "selected": 580117,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "30 Sep 15:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 6,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 64,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-09-30T14:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 7
                },
                {
                  "transfers_out": 82339,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 750,
                  "transfers_balance": -81589,
                  "goals_scored": 0,
                  "id": 4034,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 499272,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "14 Oct 12:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 10,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 75,
                  "was_home": false,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-10-14T11:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 8
                },
                {
                  "transfers_out": 21306,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 874,
                  "transfers_balance": -20432,
                  "goals_scored": 0,
                  "id": 4591,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 479180,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "21 Oct 15:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 8,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 83,
                  "was_home": false,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 1,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-10-21T14:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 9
                },
                {
                  "transfers_out": 19890,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 3700,
                  "transfers_balance": -16190,
                  "goals_scored": 0,
                  "id": 5150,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 463435,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "28 Oct 12:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 17,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 98,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-10-28T11:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 10
                },
                {
                  "transfers_out": 14756,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 2387,
                  "transfers_balance": -12369,
                  "goals_scored": 0,
                  "id": 5713,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 451378,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "05 Nov 16:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 5,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 101,
                  "was_home": false,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-11-05T16:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 11
                },
                {
                  "transfers_out": 11229,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 1,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "59.0",
                  "key_passes": 2,
                  "transfers_in": 44317,
                  "transfers_balance": 33088,
                  "goals_scored": 1,
                  "id": 6279,
                  "own_goals": 0,
                  "team_h_score": 4,
                  "selected": 485707,
                  "creativity": "34.8",
                  "kickoff_time_formatted": "18 Nov 17:30",
                  "bonus": 2,
                  "big_chances_created": 0,
                  "ict_index": "13.9",
                  "total_points": 12,
                  "penalties_missed": 0,
                  "attempted_passes": 64,
                  "opponent_team": 13,
                  "completed_passes": 54,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 118,
                  "was_home": true,
                  "recoveries": 7,
                  "clean_sheets": 0,
                  "assists": 1,
                  "team_a_score": 1,
                  "open_play_crosses": 1,
                  "clearances_blocks_interceptions": 1,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-11-18T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 3,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 38,
                  "dribbles": 3,
                  "threat": "45.0",
                  "tackled": 3,
                  "big_chances_missed": 0,
                  "minutes": 69,
                  "round": 12
                },
                {
                  "transfers_out": 5401,
                  "yellow_cards": 0,
                  "tackles": 2,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "27.6",
                  "key_passes": 2,
                  "transfers_in": 385588,
                  "transfers_balance": 380187,
                  "goals_scored": 0,
                  "id": 6848,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 874149,
                  "creativity": "35.6",
                  "kickoff_time_formatted": "25 Nov 15:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "12.1",
                  "total_points": 3,
                  "penalties_missed": 0,
                  "attempted_passes": 110,
                  "opponent_team": 3,
                  "completed_passes": 95,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 124,
                  "was_home": true,
                  "recoveries": 10,
                  "clean_sheets": 1,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 3,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-11-25T15:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 16,
                  "dribbles": 2,
                  "threat": "58.0",
                  "tackled": 3,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 13
                },
                {
                  "transfers_out": 37374,
                  "yellow_cards": 0,
                  "tackles": 2,
                  "goals_conceded": 2,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "14.0",
                  "key_passes": 1,
                  "transfers_in": 72062,
                  "transfers_balance": 34688,
                  "goals_scored": 0,
                  "id": 7418,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 912931,
                  "creativity": "14.0",
                  "kickoff_time_formatted": "28 Nov 20:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "5.2",
                  "total_points": 5,
                  "penalties_missed": 0,
                  "attempted_passes": 46,
                  "opponent_team": 18,
                  "completed_passes": 34,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 133,
                  "was_home": false,
                  "recoveries": 11,
                  "clean_sheets": 0,
                  "assists": 1,
                  "team_a_score": 4,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 3,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-11-28T20:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 2,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 25,
                  "dribbles": 4,
                  "threat": "24.0",
                  "tackled": 2,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 14
                },
                {
                  "transfers_out": 52800,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 1,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "38.6",
                  "key_passes": 2,
                  "transfers_in": 46106,
                  "transfers_balance": -6694,
                  "goals_scored": 0,
                  "id": 7989,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 909960,
                  "creativity": "22.8",
                  "kickoff_time_formatted": "02 Dec 17:30",
                  "bonus": 0,
                  "big_chances_created": 1,
                  "ict_index": "6.9",
                  "total_points": 5,
                  "penalties_missed": 0,
                  "attempted_passes": 22,
                  "opponent_team": 1,
                  "completed_passes": 18,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 141,
                  "was_home": false,
                  "recoveries": 8,
                  "clean_sheets": 0,
                  "assists": 2,
                  "team_a_score": 3,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 3,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-02T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 2,
                  "red_cards": 1,
                  "loaned_out": 0,
                  "value": 80,
                  "element": 282,
                  "bps": 20,
                  "dribbles": 1,
                  "threat": "8.0",
                  "tackled": 1,
                  "big_chances_missed": 0,
                  "minutes": 73,
                  "round": 15
                },
                {
                  "transfers_out": 334821,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 7086,
                  "transfers_balance": -327735,
                  "goals_scored": 0,
                  "id": 8563,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 583340,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "10 Dec 16:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 11,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 155,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-10T16:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 16
                },
                {
                  "transfers_out": 48503,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 2830,
                  "transfers_balance": -45673,
                  "goals_scored": 0,
                  "id": 9140,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 538286,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "13 Dec 20:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 2,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 164,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-13T20:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 17
                },
                {
                  "transfers_out": 22525,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 3722,
                  "transfers_balance": -18803,
                  "goals_scored": 0,
                  "id": 9718,
                  "own_goals": 0,
                  "team_h_score": 1,
                  "selected": 520095,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "17 Dec 14:15",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 19,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 180,
                  "was_home": false,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-17T14:15:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 18
                },
                {
                  "transfers_out": 10683,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 2,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "19.0",
                  "key_passes": 1,
                  "transfers_in": 153590,
                  "transfers_balance": 142907,
                  "goals_scored": 0,
                  "id": 10298,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 668018,
                  "creativity": "14.7",
                  "kickoff_time_formatted": "23 Dec 19:45",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "5.1",
                  "total_points": 2,
                  "penalties_missed": 0,
                  "attempted_passes": 62,
                  "opponent_team": 9,
                  "completed_passes": 45,
                  "target_missed": 2,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 185,
                  "was_home": false,
                  "recoveries": 9,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 9,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-23T19:45:00Z",
                  "penalties_saved": 0,
                  "fouls": 2,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 14,
                  "dribbles": 2,
                  "threat": "17.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 19
                },
                {
                  "transfers_out": 17161,
                  "yellow_cards": 0,
                  "tackles": 3,
                  "goals_conceded": 2,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "19.6",
                  "key_passes": 2,
                  "transfers_in": 45771,
                  "transfers_balance": 28610,
                  "goals_scored": 0,
                  "id": 10883,
                  "own_goals": 0,
                  "team_h_score": 2,
                  "selected": 699730,
                  "creativity": "31.3",
                  "kickoff_time_formatted": "26 Dec 15:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "8.0",
                  "total_points": 2,
                  "penalties_missed": 0,
                  "attempted_passes": 84,
                  "opponent_team": 4,
                  "completed_passes": 74,
                  "target_missed": 3,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 196,
                  "was_home": true,
                  "recoveries": 13,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": 2,
                  "open_play_crosses": 1,
                  "clearances_blocks_interceptions": 1,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-26T15:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 20,
                  "dribbles": 2,
                  "threat": "29.0",
                  "tackled": 2,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 20
                },
                {
                  "transfers_out": 46503,
                  "yellow_cards": 0,
                  "tackles": 1,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "9.2",
                  "key_passes": 0,
                  "transfers_in": 34953,
                  "transfers_balance": -11550,
                  "goals_scored": 0,
                  "id": 11469,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 690653,
                  "creativity": "5.8",
                  "kickoff_time_formatted": "30 Dec 17:30",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "2.3",
                  "total_points": 3,
                  "penalties_missed": 0,
                  "attempted_passes": 62,
                  "opponent_team": 14,
                  "completed_passes": 55,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 206,
                  "was_home": true,
                  "recoveries": 4,
                  "clean_sheets": 1,
                  "assists": 0,
                  "team_a_score": 0,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 2,
                  "penalties_conceded": 0,
                  "offside": 1,
                  "ea_index": 0,
                  "kickoff_time": "2017-12-30T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 1,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 11,
                  "dribbles": 1,
                  "threat": "8.0",
                  "tackled": 2,
                  "big_chances_missed": 0,
                  "minutes": 90,
                  "round": 21
                },
                {
                  "transfers_out": 73053,
                  "yellow_cards": 0,
                  "tackles": 1,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "51.2",
                  "key_passes": 5,
                  "transfers_in": 14621,
                  "transfers_balance": -58432,
                  "goals_scored": 0,
                  "id": 11995,
                  "own_goals": 0,
                  "team_h_score": 0,
                  "selected": 633117,
                  "creativity": "57.4",
                  "kickoff_time_formatted": "01 Jan 17:30",
                  "bonus": 3,
                  "big_chances_created": 0,
                  "ict_index": "16.1",
                  "total_points": 12,
                  "penalties_missed": 0,
                  "attempted_passes": 61,
                  "opponent_team": 7,
                  "completed_passes": 51,
                  "target_missed": 1,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 214,
                  "was_home": false,
                  "recoveries": 7,
                  "clean_sheets": 1,
                  "assists": 2,
                  "team_a_score": 2,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 3,
                  "penalties_conceded": 0,
                  "offside": 1,
                  "ea_index": 0,
                  "kickoff_time": "2018-01-01T17:30:00Z",
                  "penalties_saved": 0,
                  "fouls": 2,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 32,
                  "dribbles": 2,
                  "threat": "52.0",
                  "tackled": 1,
                  "big_chances_missed": 1,
                  "minutes": 90,
                  "round": 22
                },
                {
                  "transfers_out": 32998,
                  "yellow_cards": 0,
                  "tackles": 0,
                  "goals_conceded": 0,
                  "winning_goals": 0,
                  "errors_leading_to_goal_attempt": 0,
                  "saves": 0,
                  "influence": "0.0",
                  "key_passes": 0,
                  "transfers_in": 172650,
                  "transfers_balance": 139652,
                  "goals_scored": 0,
                  "id": 12647,
                  "own_goals": 0,
                  "team_h_score": null,
                  "selected": 780062,
                  "creativity": "0.0",
                  "kickoff_time_formatted": "15 Jan 20:00",
                  "bonus": 0,
                  "big_chances_created": 0,
                  "ict_index": "0.0",
                  "total_points": 0,
                  "penalties_missed": 0,
                  "attempted_passes": 0,
                  "opponent_team": 15,
                  "completed_passes": 0,
                  "target_missed": 0,
                  "errors_leading_to_goal": 0,
                  "loaned_in": 0,
                  "fixture": 226,
                  "was_home": true,
                  "recoveries": 0,
                  "clean_sheets": 0,
                  "assists": 0,
                  "team_a_score": null,
                  "open_play_crosses": 0,
                  "clearances_blocks_interceptions": 0,
                  "penalties_conceded": 0,
                  "offside": 0,
                  "ea_index": 0,
                  "kickoff_time": "2018-01-15T20:00:00Z",
                  "penalties_saved": 0,
                  "fouls": 0,
                  "red_cards": 0,
                  "loaned_out": 0,
                  "value": 79,
                  "element": 282,
                  "bps": 0,
                  "dribbles": 0,
                  "threat": "0.0",
                  "tackled": 0,
                  "big_chances_missed": 0,
                  "minutes": 0,
                  "round": 23
                }
              ]
            }
        """
        return requests.get("{}element-summary/{}".format(API_BASE_URL,
            player_id)).json()

    @property
    def gameweeks(self):
        """
        Returns a list containing information about all the gameweeks.
        """
        return requests.get("{}events".format(API_BASE_URL)).json()

    def gameweek(self, gameweek):
        """
        Returns information about the given gameweek.

        :param int gameweek: The gameweek (1-38)
        """
        return requests.get("{}event/{}/live".format(API_BASE_URL,
            gameweek)).json()

    @property
    def game_settings(self):
        """
        Returns a dictionary containing the Fantasy Premier League's rules.
        """
        return requests.get("{}game-settings".format(API_BASE_URL)).json()

    def classic_league(self, league_id):
        """
        Returns a dictionary containing information about the classic league 
        with the given `league_id`.

        :param string league_id: A league's id
        """
        return requests.get("{}leagues-classic-standings/{}".format(
            API_BASE_URL, league_id)).json()

    def h2h_league(self, league_id):
        """
        Returns a dictionary containing information about the h2h league with 
        the given `league_id`.

        :param string league_id: A league's id
        """
        return requests.get("{}leagues-h2h-standings/{}".format(
            API_BASE_URL, league_id)).json()